/**
 * Any CSS included here will be global. The classic template
 * bundles Infima by default. Infima is a CSS framework designed to
 * work well for content-centric websites.
 */

/* You can override the default Infima variables here. */
:root {
  --ifm-color-primary: #08738f;
  --ifm-color-primary-dark: #076781;
  --ifm-color-primary-darker: #07627a;
  --ifm-color-primary-darkest: #065064;
  --ifm-color-primary-light: #097e9d;
  --ifm-color-primary-lighter: #0984a4;
  --ifm-color-primary-lightest: #0a95ba;
  --ifm-code-font-size: 95%;
  --docusaurus-highlighted-code-line-bg: rgb(24 65 100 / 0.85);
  --ifm-hover-overlay: rgb(242, 252, 255);
  --main-bg-color: #f9f9f9;
  --layout-bg-color: #fff;
  --border-color: #e5e7eb;

  --navbar-bg-opacity: 1;
  --ifm-navbar-background-color: rgb(255 255 255 / var(--navbar-bg-opacity));
  --ifm-code-padding-horizontal: 0.3rem;
}

/* For readability concerns, you should choose a lighter palette in dark mode. */
[data-theme='dark'] {
  --ifm-color-primary: #0a95ba;
  --ifm-color-primary-dark: #0986a7;
  --ifm-color-primary-darker: #087f9e;
  --ifm-color-primary-darkest: #076882;
  --ifm-color-primary-light: #0ba4cd;
  --ifm-color-primary-lighter: #0babd6;
  --ifm-color-primary-lightest: #0dc2f2;
  --docusaurus-highlighted-code-line-bg: rgba(0, 0, 0, 0.3);
  --main-bg-color: #1e2327;
  --layout-bg-color: #151a1c;
  --border-color: rgb(71 71 71 / 0.5);

  --ifm-navbar-background-color: rgb(18 20 24 / var(--navbar-bg-opacity));
}

.header-github-link {
  width: 32px;
  height: 32px;
  padding: 6px;
  margin-right: 4px;
  border-radius: 50%;
  transition: background var(--ifm-transition-fast);
}

.header-github-link:hover {
  background: var(--ifm-color-emphasis-200);
}

.header-github-link:before {
  content: '';
  height: 100%;
  display: block;
  background: url("data:image/svg+xml,%3Csvg viewBox='0 0 24 24' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M12 .297c-6.63 0-12 5.373-12 12 0 5.303 3.438 9.8 8.205 11.385.6.113.82-.258.82-.577 0-.285-.01-1.04-.015-2.04-3.338.724-4.042-1.61-4.042-1.61C4.422 18.07 3.633 17.7 3.633 17.7c-1.087-.744.084-.729.084-.729 1.205.084 1.838 1.236 1.838 1.236 1.07 1.835 2.809 1.305 3.495.998.108-.776.417-1.305.76-1.605-2.665-.3-5.466-1.332-5.466-5.93 0-1.31.465-2.38 1.235-3.22-.135-.303-.54-1.523.105-3.176 0 0 1.005-.322 3.3 1.23.96-.267 1.98-.399 3-.405 1.02.006 2.04.138 3 .405 2.28-1.552 3.285-1.23 3.285-1.23.645 1.653.24 2.873.12 3.176.765.84 1.23 1.91 1.23 3.22 0 4.61-2.805 5.625-5.475 5.92.42.36.81 1.096.81 2.22 0 1.606-.015 2.896-.015 3.286 0 .315.21.69.825.57C20.565 22.092 24 17.592 24 12.297c0-6.627-5.373-12-12-12'/%3E%3C/svg%3E") no-repeat;
}

html[data-theme='dark'] .header-github-link:before {
  background: url("data:image/svg+xml,%3Csvg viewBox='0 0 24 24' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath fill='white' d='M12 .297c-6.63 0-12 5.373-12 12 0 5.303 3.438 9.8 8.205 11.385.6.113.82-.258.82-.577 0-.285-.01-1.04-.015-2.04-3.338.724-4.042-1.61-4.042-1.61C4.422 18.07 3.633 17.7 3.633 17.7c-1.087-.744.084-.729.084-.729 1.205.084 1.838 1.236 1.838 1.236 1.07 1.835 2.809 1.305 3.495.998.108-.776.417-1.305.76-1.605-2.665-.3-5.466-1.332-5.466-5.93 0-1.31.465-2.38 1.235-3.22-.135-.303-.54-1.523.105-3.176 0 0 1.005-.322 3.3 1.23.96-.267 1.98-.399 3-.405 1.02.006 2.04.138 3 .405 2.28-1.552 3.285-1.23 3.285-1.23.645 1.653.24 2.873.12 3.176.765.84 1.23 1.91 1.23 3.22 0 4.61-2.805 5.625-5.475 5.92.42.36.81 1.096.81 2.22 0 1.606-.015 2.896-.015 3.286 0 .315.21.69.825.57C20.565 22.092 24 17.592 24 12.297c0-6.627-5.373-12-12-12'/%3E%3C/svg%3E") no-repeat;
}

.flex {
  display: flex !important;
}

.justify-between {
  justify-content: space-between;
}

.navbar {
  box-shadow: none;
  border-bottom: 1px solid var(--border-color);
}

@media (min-width: 997px) {
  :root {
    --navbar-bg-opacity: 0.2;
  }

  .navbar {
    backdrop-filter: blur(10px);
  }

  .menu {
    font-weight: initial;
    font-size: 0.875rem;
    margin: 0.5rem;
    border: 1px solid var(--border-color);
    border-radius: 0.75rem;
    background: var(--layout-bg-color);
    padding: 0.75rem !important;
  }
}

.navbar__item {
  color: var(--ifm-color-primary-darkest);
}

.navbar__search-input {
  border-radius:  0.375rem;
  box-shadow: 0px 1px 0px #7b7b7b73, inset 0px 2px 8px 0px #c4c4c496;
  border: 1px solid #aaaaaa;
}

.main-wrapper {
  background: var(--main-bg-color);
}

body {
  background: var(--layout-bg-color);
}

.theme-doc-sidebar-container {
  border: none !important;
}

.theme-admonition {
  border: 1px solid var(--border-color);
  box-shadow: none;
}

.tabs-container {
  border: 1px solid var(--border-color);
  padding: 0 1rem 1rem;
  border-radius: 0.5rem;
}

.footer {
  border: 1px solid var(--border-color);
  background-color: var(--layout-bg-color)
}

.table-of-contents__link--active {
  color: var(--ifm-breadcrumb-color-active);
  background: var(--ifm-breadcrumb-item-background-active);
  padding: 0.375rem 0.5rem;
  border-radius: 0 var(--ifm-breadcrumb-border-radius) var(--ifm-breadcrumb-border-radius) 0;
  border-left: 1px solid var(--ifm-breadcrumb-color-active);
}
